uniform sampler2D cube;
uniform sampler2D   normalMap;
uniform sampler2D   refractionMap;
varying vec4 distance;
varying vec4 cPos;
varying vec2 texcoords;
varying vec2 texcoords2;

varying vec4 projCoords;

void main()
{
	//projected texture coordinates
	vec2 refrCoords = projCoords.xy/projCoords.w;
	refrCoords = refrCoords + 1.0;
	refrCoords = refrCoords * 0.5;

	//load -y scrolling normal map
	vec4 normal1 = texture2D(normalMap, texcoords);
	normal1 = normal1*2.0 - vec4(1.0);
	normal1 = normalize(normal1);

	//load +y scrolling normal map 
	vec4 normal2 = texture2D(normalMap, texcoords2);
	normal2 = normal2*2.0 - vec4(1.0);
	normal2 = normalize(normal2);

	//get average of normals
	vec4 normal = normalize((normal1+normal2)*0.5);


	//clamp texture coordiantes to avoid artifacts
	refrCoords = clamp(refrCoords+normal.xy*0.01, 0.001, 0.999);	
	vec2 reflCoords = clamp(refrCoords+normal.xy*0.05, 0.001, 0.999);

	//load reflection texture
	vec4 reflection = texture2D( cube, reflCoords);	

	//load refraction texture
	vec4 refraction = texture2D(refractionMap, refrCoords);

	//calculate fresnel
	vec4 cPosn = normalize(vec4(cPos.x, cPos.y, cPos.z,0.0));
	float ndotv = max(0.0,dot(normal.yzxw, cPosn));
	float fresnel = 1.0-ndotv;

	//interpolate using fresnel and distance to ground
	float interpolator = clamp(fresnel*(1.0-refraction.a), 0.0, 1.0);
	
	gl_FragColor =mix(refraction,reflection, interpolator);
	gl_FragColor.a = distance.z/distance.w; //store depth in alpha channel
	
}