varying vec4 vtol; 
varying vec4 vtov; 
varying vec4 texcoords;
varying vec4 projCoords;
varying vec4 distance;

uniform sampler2D normalMap;
uniform sampler2D baseMap;
uniform sampler2DShadow depthMap;
uniform sampler2D detailMap;

void main()
{

	vec4 light = normalize(vtol);
	vec4 viewpos = normalize(vtov);
	vec4 ambient = vec4(0.5,0.5,0.5,0.0);
	vec4 ofive = vec4(0.5,0.5,0.5, 1.0);
	vec4 two = vec4(2.0,2.0,2.0, 1.0);

	//load diffuse texture
	vec4 base = texture2D(baseMap, texcoords.xy);

	//load normal map
	vec4 normal = texture2D(normalMap, texcoords.xy);
	normal  = (normal-ofive)*two;
	normal = normalize(normal);

	//load detail normal map
	vec4 detail = texture2D(detailMap, texcoords.xy*6.0);
	detail  = (detail-ofive)*two;
	detail = normalize(detail);

	//calculate diffuse lighting
	float diffuse = max(dot(normal,light), 0.0);
	float detdiff = max(dot(detail,light), 0.0);


	//shadow map coordinates
	vec3 shadowCoords = projCoords.xyz;
	shadowCoords.z = shadowCoords.z - 0.0001;
	shadowCoords = shadowCoords.xyz/projCoords.w;

	//blur shadow
	vec4 depth = shadow2D(depthMap, shadowCoords);
	depth += shadow2D(depthMap, shadowCoords+vec3( 0.0004, 0.0004,0.0));
	depth += shadow2D(depthMap, shadowCoords+vec3(-0.0004,-0.0004,0.0));
	depth += shadow2D(depthMap, shadowCoords+vec3( 0.0004,-0.0004,0.0));
	depth += shadow2D(depthMap, shadowCoords+vec3(-0.0004, 0.0004,0.0));
	depth += shadow2D(depthMap, shadowCoords+vec3( 0.0004, 0.000, 0.0));
	depth += shadow2D(depthMap, shadowCoords+vec3(-0.0004, 0.000, 0.0));
	depth += shadow2D(depthMap, shadowCoords+vec3( 0.000 ,-0.0004,0.0));
	depth += shadow2D(depthMap, shadowCoords+vec3( 0.000 , 0.0004,0.0));
	depth *= 0.111;
	

	vec4 final = ambient*base+base*detdiff*diffuse*depth;
	gl_FragColor =vec4(final.xyz,distance.z/distance.w); //store depth in alpha channel

}